# PutRevproAccCodeResponse


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**success** | **bool** |  | [optional] 

## Example

```python
from zuora_sdk.models.put_revpro_acc_code_response import PutRevproAccCodeResponse

# TODO update the JSON string below
json = "{}"
# create an instance of PutRevproAccCodeResponse from a JSON string
put_revpro_acc_code_response_instance = PutRevproAccCodeResponse.from_json(json)
# print the JSON string representation of the object
print(PutRevproAccCodeResponse.to_json())

# convert the object into a dict
put_revpro_acc_code_response_dict = put_revpro_acc_code_response_instance.to_dict()
# create an instance of PutRevproAccCodeResponse from a dict
put_revpro_acc_code_response_from_dict = PutRevproAccCodeResponse.from_dict(put_revpro_acc_code_response_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


